#include <avr/io.h>
#include <avr/delay.h>
#include "lcd.h"

#define Clear_Display		0x01
#define Home_Display		0x02
#define Cursoroff_Display	0x0C
#define Cursoron_Display	0x0F

static volatile unsigned char rs;

void SPI_sende (unsigned char aData) 
{
	SPDR = aData;
	while(!(SPSR & (1<<SPIF)));
}

void writecmd (unsigned char cmd)
{
	unsigned char lower;
	unsigned char upper;
	unsigned char startbyte;
	lower = cmd % 16;
	upper = cmd / 16;
	if (rs != 0)
	{
		startbyte = 0x1F;
		SPI_sende (startbyte);
	}
	SPI_sende (lower);
	SPI_sende (upper);
	rs = 0;
	delay_us(50);
}

void writedat (unsigned char dat)
{
	unsigned char lower;
	unsigned char upper;
	unsigned char startbyte;
	lower = dat % 16;
	upper = dat / 16;
	if (rs !=1)
	{
		startbyte = 0x5F;
		SPI_sende (startbyte);
	}
	SPI_sende (lower);
	SPI_sende (upper);
	rs = 1;
}

void lcd_init(void)	
{
  	DDRB = (1<<DDB3)|(1<<DDB5)|(1<<DDB2);			
	SPCR = (1<<SPE)|(1<<MSTR)|(1<<SPR0)|(1<<DORD);
	delay_ms(30);
	rs = 1;
	writecmd(0x34);
	writecmd(0x09);
	writecmd(0x30);
	writecmd(0x0F);
	delay_ms(2);
	writecmd(0x01);
	delay_ms(2);
	writecmd(0x06);
}

void lcd_chr(unsigned char c)
{
writedat(c);
}

void lcd_str(const char *s)
{
    register unsigned char c;
    while ( (c = *s++) )
    {
     lcd_chr(c);
    }
}

void lcd_clear(void)
{
	writecmd(Clear_Display);
	delay_ms(2);
}

void lcd_home(void)
{
	writecmd(Home_Display);
	delay_ms(2);
}

void lcd_cursoroff(void)
{
	writecmd(Cursoroff_Display);
}

void lcd_cursoron(void)
{
	writecmd(Cursoron_Display);
}

void gotoyx(unsigned char y, unsigned char x)
{
	unsigned char line = 0;
	switch(y)
      	{
         	case 1: line = 0X00;
         		break;
         	case 2: line = 0X20;
                  	break;
         	case 3: line = 0X40;
         		break;
         	case 4: line = 0X60;
        		break;
	}     
	line = (line+0x80);	
	line = (line+x);
	writecmd(line);
}


